chrome.runtime.onMessage.addListener(function(request, sender, sendResponse) {
    if (request.type === 'SAVE_JOB_DATA') {
        chrome.storage.local.get(['jobData'], function(result) {
            let existingData = result.jobData || [];
            console.log('加载现有数据成功，数据数量:', existingData.length);
            console.log('现有数据:', existingData);

            let newData = request.data;

            if (newData.length === 0) {
                console.log('没有新数据需要添加。');
                return; // 如果没有新数据，则直接返回
            }

            // 使用 Map 来存储现有数据，键为详情链接
            let dataMap = new Map(existingData.map(item => [item.详情链接, item]));
            console.log('现有数据已映射到 Map 中');

            let addedCount = 0;

            // 遍历新数据，检查是否已存在
            newData.forEach(job => {
                if (!dataMap.has(job.详情链接)) {
                    dataMap.set(job.详情链接, job);
                    addedCount++;
                    console.log(`添加新数据：${JSON.stringify(job)}`);
                } else {
                    console.log(`重复数据未添加：${job.详情链接}`);
                }
            });

            // 将 Map 转换回数组
            let updatedData = Array.from(dataMap.values());
            console.log('合并后的数据数量:', updatedData.length, '新增数据数量:', addedCount);

            chrome.storage.local.set({ jobData: updatedData }, function() {
                if (chrome.runtime.lastError) {
                    console.error('保存数据时出错:', chrome.runtime.lastError);
                    chrome.runtime.sendMessage({
                        action: 'dataFetchFailed',
                        error: chrome.runtime.lastError.message
                    });
                } else {
                    console.log('数据已成功保存');
                    chrome.runtime.sendMessage({
                        action: 'dataFetched',
                        data: updatedData,
                        addedCount: addedCount
                    });
                }
            });
        });
    }
});

 

//获取JD详情
chrome.runtime.onMessage.addListener((request, sender, sendResponse) => {
    if (request.action === "fetchJobDetails") {
        fetchJobDetailsAsync(request.url, sender.tab.id);
        sendResponse({ status: "started" }); // 立即回复，表示任务已开始
        return false; // 不需要保持消息通道开放
    }
});

async function fetchJobDetailsAsync(url) {
    let attempts = 0;
    const maxAttempts = 3; // 设置最大重试次数为3次
    while (attempts < maxAttempts) {
        try {
            const tab = await chrome.tabs.create({ url: url, active: false });
            await new Promise(resolve => setTimeout(resolve, 1000 + attempts * 500)); // 增加等待时间，每次重试等待更长
            const results = await chrome.scripting.executeScript({
                target: { tabId: tab.id },
                function: scrapeJobDetails,
            });
            await chrome.tabs.remove(tab.id);
            if (results && results[0] && results[0].result) {
                // 成功获取数据后，发送消息到options页面并结束重试
                chrome.runtime.sendMessage({
                    action: "jobDetailsFetched",
                    success: true,
                    data: results[0].result,
                    url: url
                });
                return;
            } else {
                throw new Error('未能获取职位详情');
            }
        } catch (error) {
            attempts++;
            console.error(`尝试 ${attempts} 失败:`, error);
            if (attempts === maxAttempts) {
                // 达到最大重试次数后，发送失败消息
                chrome.runtime.sendMessage({
                    action: "jobDetailsFetched",
                    success: false,
                    error: error.message,
                    url: url
                });
            }
        }
    }
}

function scrapeJobDetails() {
    try {
        const jobDescription = document.querySelector('.job-sec-text')?.textContent.trim() || '未找到职位描述';
        const communicationButton = document.querySelector('.btn-startchat');
        let hasCommunicated = '未知';
        if (communicationButton) {
            hasCommunicated = communicationButton.textContent.trim() === '继续沟通' ? '是' : '否';
        }
        // 优先获取在线活跃类型
        const activeTime = document.querySelector('.boss-online-tag')?.textContent.trim() 
        || document.querySelector('.boss-active-time')?.textContent.trim() 
        || '活跃时间未找到';

        console.log(activeTime);

        return { jobDescription, hasCommunicated, activeTime };
    } catch (error) {
        console.error('抓取职位详情时出错:', error);
        return { error: error.message };
    }
}

