// 主程序代码

// 定义全局变量
let isFetching = false;      // 是否正在抓取JD详情
let jobQueue = [];           // 需要抓取的职位队列
let currentIndex = 0;        // 当前正在抓取的职位索引
let btn, loadingIcon;        // 按钮和加载图标元素

// 页面加载完成后执行
document.addEventListener('DOMContentLoaded', function() {
    // 初始化Tab切换功能
    setupTabs();

    // 初始化运行模式切换
    setupRunModeToggle();

    // 加载设置
    loadSettings();

    // 初始化设置表单提交事件
    setupSettingsForm();

    // 初始化删除选中项按钮
    setupDeleteSelectedButton();

    // 初始化获取JD按钮
    setupGetJDButton();

    // 初始化数据导入、导出和重置按钮
    setupDataImportExportButtons();

    // 初始化全选功能
    setupSelectAll();

    // 初始化职位表格
    loadJobTable();

    // 初始化AI评分按钮
    setupProcessDataButton();

    // 初始化弹出层关闭按钮的事件监听器
    setupPopupCloseButton();
    //检查更新
    checkForUpdates()
    //加载隐藏岗位页面表格
    loadHiddenJobTable(); // 重新加载隐藏岗位页面表格
});

document.addEventListener('DOMContentLoaded', function() {
    var manifestData = chrome.runtime.getManifest();
    var version = manifestData.version;
    document.getElementById('version-number').textContent = '版本号：' + version;
});

// 定义检查更新的函数
function checkForUpdates() {
    fetch('https://100resume.aitoolhub.top/download/update-info.json')
      .then(response => response.json())
      .then(data => {
        const currentVersion = chrome.runtime.getManifest().version;
        const latestVersion = data.latestVersion;

        // 更新日志
        updateChangelog(data.logs);
  
        if (latestVersion > currentVersion) {
          console.log('有新版本可用:', latestVersion);
          // 可以在这里添加更新通知逻辑
          // 调用通知显示函数
        showUpdateNotification(latestVersion, data.Url);
        } else {
          console.log('当前已是最新版本.');
        }
      })
      .catch(error => console.error('更新检查失败:', error));
  }
  
// 更新日志
function updateChangelog(logs) {
    const changelogList = document.getElementById('changelog-list');
    changelogList.innerHTML = ''; // 清空当前的日志列表

    logs.forEach(log => {
        const li = document.createElement('li');
        li.innerHTML = `<strong>${log.version}</strong> - ${log.description}`;
        changelogList.appendChild(li);
    });
}

//通知更新
function showUpdateNotification(version, url) {
    chrome.notifications.create('updateNotification', {
      type: 'basic',
      iconUrl: 'icons/icon.png',
      title: '更新可用',
      message: `有新的版本可用: ${version}！`,
      buttons: [{title: '下载更新'}],
      priority: 2
    }, function(notificationId) {});
  
    chrome.notifications.onButtonClicked.addListener(function(notifId, btnIdx) {
      if (notifId === 'updateNotification' && btnIdx === 0) {
        window.open(url);
      }
    });
  }
  
// 设置弹出层关闭按钮的事件监听器
function setupPopupCloseButton() {
    const closeButton = document.getElementById('closePopupButton');
    if (closeButton) {
        closeButton.addEventListener('click', hidePopup);
    } else {
        console.error('未找到关闭按钮元素，请检查HTML代码。');
    }
}

// 隐藏弹出层
function hidePopup() {
    document.getElementById('overlay').style.display = 'none';
}

// 显示弹出层
function showPopup() {
    document.getElementById('overlay').style.display = 'block';
}


// 设置Tab切换功能
function setupTabs() {
    const tabButtons = document.querySelectorAll('.tablinks');
    const tabContents = document.querySelectorAll('.tabcontent');

    function openTab(tabName) {
        tabContents.forEach(content => {
            content.style.display = 'none';
        });
        tabButtons.forEach(button => {
            button.classList.remove('active');
        });
        document.getElementById(tabName).style.display = 'block';
        document.querySelector(`[data-tab="${tabName}"]`).classList.add('active');
    }

    tabButtons.forEach(button => {
        button.addEventListener('click', function() {
            openTab(this.getAttribute('data-tab'));
        });
    });

    // 默认打开"ResumeAnalysis"标签
    openTab('ResumeAnalysis');
}

// 加载设置
function loadSettings() {
    const runModeText = document.getElementById('runModeText');
    chrome.storage.local.get(['pagesToScrape', 'model', 'runMode', 'apiKey', 'resume', 'greetingMessage'], function(data) {
        document.getElementById('pages').value = data.pagesToScrape || 5;
        document.getElementById('model').value = data.model || 'glm-4-flash';
        document.getElementById('runMode').checked = data.runMode || false;
        document.getElementById('apiKey').value = data.apiKey || '';
        document.getElementById('resume').value = data.resume || '';
        document.getElementById('greetingMessage').value = data.greetingMessage || '我对该岗位非常感兴趣，请问能否进一步沟通？';
        runModeText.textContent = data.runMode ? '在线' : '本地';
    });
    // 在初始化时设置打招呼语默认值
chrome.storage.local.get('shouldGreet', function(data) {
    if (data.shouldGreet === undefined) {
        chrome.storage.local.set({ shouldGreet: true });
    }
});
}

// 设置运行模式切换的事件监听器
function setupRunModeToggle() {
    const runModeToggle = document.getElementById('runMode');
    const runModeText = document.getElementById('runModeText');

    runModeToggle.addEventListener('change', function() {
        runModeText.textContent = this.checked ? '在线' : '本地';
    });
}

// 设置表单提交事件监听器
function setupSettingsForm() {
    const settingsForm = document.getElementById('settingsForm');
    settingsForm.addEventListener('submit', function(e) {
        e.preventDefault();
        saveSettings();
    });
}

// 保存设置
function saveSettings() {
    const pages = document.getElementById('pages').value;
    const model = document.getElementById('model').value;
    const runMode = document.getElementById('runMode').checked;
    const apiKey = document.getElementById('apiKey').value;
    const resume = document.getElementById('resume').value;
    const greetingMessage = document.getElementById('greetingMessage').value;
    const runModeText = document.getElementById('runModeText');

    runModeText.textContent = runMode ? '在线' : '本地';

    chrome.storage.local.set({
        pagesToScrape: pages,
        model: model,
        runMode: runMode,
        apiKey: apiKey,
        resume: resume,
        greetingMessage: greetingMessage
    }, function() {
        alert('设置已保存');
    });
}

// 设置删除选中项按钮
function setupDeleteSelectedButton() {
    document.getElementById('deleteSelected').addEventListener('click', function() {
        chrome.storage.local.get('jobData', function(data) {
            if (data.jobData) {
                const checkboxes = document.querySelectorAll('.row-checkbox:checked');
                const indicesToDelete = Array.from(checkboxes).map(cb => parseInt(cb.getAttribute('data-index')));
                const updatedJobData = data.jobData.filter((_, index) => !indicesToDelete.includes(index));
                chrome.storage.local.set({ jobData: updatedJobData }, function() {
                    alert('选中项已删除');
                    loadJobTable(); // 重新加载表格
                });
            }
        });
    });
}

// 设置获取JD按钮
function setupGetJDButton() {
    btn = document.getElementById('getJD');
    loadingIcon = document.getElementById('loadingIcon');

    btn.addEventListener('click', function() {
        if (!isFetching) {
            startFetching();
        } else {
            stopFetching();
        }
    });
}

// 设置数据导入、导出和重置按钮
function setupDataImportExportButtons() {
    document.getElementById('importConfig').addEventListener('click', function() {
        const input = document.createElement('input');
        input.type = 'file';
        input.accept = '.json';
        input.onchange = function(event) {
            const file = event.target.files[0];
            const reader = new FileReader();
            reader.onload = function(e) {
                const config = JSON.parse(e.target.result);
                chrome.storage.local.set(config, function() {
                    alert('配置已导入');
                    loadSettings();
                });
            };
            reader.readAsText(file);
        };
        input.click();
    });

    document.getElementById('exportConfig').addEventListener('click', function() {
        chrome.storage.local.get(null, function(data) {
            const blob = new Blob([JSON.stringify(data)], { type: "application/json" });
            const url = URL.createObjectURL(blob);
            const a = document.createElement('a');
            a.href = url;
            a.download = 'config.json';
            a.click();
        });
    });

    document.getElementById('resetSettings').addEventListener('click', function() {
        const defaultSettings = {
            pagesToScrape: 5,
            model: 'glm-4-flash',
            runMode: false,
            apiKey: '',
            resume: ''
        };
        chrome.storage.local.set(defaultSettings, function() {
            alert('设置已重置');
            loadSettings();
        });
    });
}

// 设置全选功能
function setupSelectAll() {
    document.getElementById('select-all').addEventListener('change', function(e) {
        const checkboxes = document.querySelectorAll('.row-checkbox');
        checkboxes.forEach(cb => cb.checked = e.target.checked);
    });
}


// 加载职位表格
function loadJobTable() {
    chrome.storage.local.get('jobData', function(data) {
        console.log('加载的全部职位数据:', data.jobData);
        const tbody = document.querySelector('#job-table tbody');
        tbody.innerHTML = '';
        if (data.jobData) {
            data.jobData.forEach((job, index) => {
                if (job.是否隐藏 === '是') {
                    return; // 跳过已隐藏的岗位
                }
                const row = tbody.insertRow();
                let rowClass = 'state-initial';
                
                if (job.activeTime) rowClass = 'state-described';
                if (job.AI评分结果 !== undefined) rowClass = 'state-scored';
                row.className = rowClass;
                // 在生成每一行时，添加数据属性
                row.dataset.jobLink = job.详情链接 || '#';
                row.innerHTML = `
                    <td><input type="checkbox" class="row-checkbox" data-index="${index}"></td>
                    <td>${job.职位名称 || 'N/A'}</td>
                    <td>${job.工作地点 || 'N/A'}</td>
                    <td>${job.薪资 || 'N/A'}</td>
                    <td>${job.公司名称 || 'N/A'}</td>
                    <td>${job.工作经验 || 'N/A'}</td>
                    <td>${job.学历要求 || 'N/A'}</td>
                    <td class="job-benefits-column" title="${job.职位福利 || 'N/A'}">${job.职位福利 || 'N/A'}</td>
                    <td>${job.activeTime || 'N/A'}</td>
                    <td>${job.抓取时间 || 'N/A'}</td>
                    <td>${job.hasCommunicated || 'N/A'}</td>
                    <td>${job.AI评分结果 !== undefined ? job.AI评分结果 : 'N/A'}</td>
                    <td><button class="details-btn" data-index="${index}">详情</button></td>
                `;
            });
            // 为所有详情按钮添加点击事件监听器
            const detailButtons = document.querySelectorAll('.details-btn');
            detailButtons.forEach(button => {
                button.addEventListener('click', showJobDetails);
            });
        }
    });
}


//AI评分排序
document.addEventListener('DOMContentLoaded', function() {
    const sortScoreHeader = document.getElementById('sortScore');

    sortScoreHeader.addEventListener('click', function() {
        sortTableByScore();
    });
});

function sortTableByScore() {
    let table = document.getElementById("job-table");
    let tbody = table.tBodies[0]; // 获取 tbody
    let rowsArray = Array.from(tbody.rows); // 获取所有行

    // 使用一个标志来切换排序方式：升序或降序
    let sortDescending = table.dataset.sortDescending === 'true';

    // 排序逻辑
    rowsArray.sort(function(rowA, rowB) {
        let scoreA = rowA.getElementsByTagName("TD")[11].textContent.trim();
        let scoreB = rowB.getElementsByTagName("TD")[11].textContent.trim();
        let valueA = scoreA === '' ? 0 : Number(scoreA);
        let valueB = scoreB === '' ? 0 : Number(scoreB);
        return sortDescending ? valueB - valueA : valueA - valueB;
    });

    // 清空 tbody 并重新插入排序后的行
    tbody.innerHTML = '';
    rowsArray.forEach(row => tbody.appendChild(row));

    // 切换排序方式
    sortDescending = !sortDescending;
    table.dataset.sortDescending = sortDescending;

    // 更新排序指示器
    updateSortIndicators('sortScore', sortDescending);
}




//活跃时间排序

document.addEventListener('DOMContentLoaded', function() {
    const sortActiveTimeHeader = document.getElementById('sortActiveTime');

    // 添加点击事件监听器，点击进行排序
    sortActiveTimeHeader.addEventListener('click', function() {
        console.log('排序活跃时间的列被点击');
        sortTableByActiveTime();
    });
});

// 根据活跃时间进行排序
function sortTableByActiveTime() {
    let table = document.getElementById("job-table");
    let tbody = table.tBodies[0];
    let rowsArray = Array.from(tbody.rows);

    let sortDescending = table.dataset.sortDescendingActiveTime === 'true';

    rowsArray.sort(function(rowA, rowB) {
        let x = rowA.getElementsByTagName("TD")[8].textContent.trim();
        let y = rowB.getElementsByTagName("TD")[8].textContent.trim();
        const xValue = convertActiveTimeToValue(x);
        const yValue = convertActiveTimeToValue(y);
        return sortDescending ? yValue - xValue : xValue - yValue;
    });

    tbody.innerHTML = '';
    rowsArray.forEach(row => tbody.appendChild(row));

    sortDescending = !sortDescending;
    table.dataset.sortDescendingActiveTime = sortDescending;

    updateSortIndicators('sortActiveTime', sortDescending);
}

function updateSortIndicators(columnId, isDescending) {
    // 移除所有表头的排序类
    document.querySelectorAll('.sortable-header').forEach(header => {
        header.classList.remove('sort-asc', 'sort-desc');
    });

    // 根据当前排序状态，添加相应的类
    const header = document.getElementById(columnId);
    if (isDescending) {
        header.classList.add('sort-desc');
    } else {
        header.classList.add('sort-asc');
    }
}



// 将活跃时间字符串转换为可比较的权重值
function convertActiveTimeToValue(activeTime) {
    // console.log(`正在转换活跃时间: ${activeTime}`);

    // 检查activeTime是否存在，如果为空，返回一个大值，以便排序时排在最后
    if (!activeTime) {
        // console.log('活跃时间为空，返回最大值');
        return 201;
    }
    
    // 处理 "在线" 优先
    if (activeTime.includes("在线")) {
        // console.log('活跃时间为在线，优先处理');
        return 0; // "在线" 权重最小
    }

    // 处理 "在线" 优先
    if (activeTime.includes("刚刚")) {
        // console.log('活跃时间为"刚刚，优先处理');
        return 1; // "在线" 权重最小
    }

    if (activeTime.includes("今日活跃")) {
        // console.log('活跃时间为今日，优先处理');
        return 2; 
    }

    if (activeTime.includes("日内活跃")) {
        const days = parseInt(activeTime.match(/\d+/)[0], 10);
        return days+1;
    }
    if (activeTime.includes("本周活跃")) {
        
        return 6; // 将周转换为天
    }

    if (activeTime.includes("周内活跃")) {
        const weeks = parseInt(activeTime.match(/\d+/)[0], 10);
        return weeks * 7; // 将周转换为天
    }

    if (activeTime.includes("本月活跃")) {
        
        return 29; // 将周转换为天
    }

    if (activeTime.includes("月内活跃")) {
        const weeks = parseInt(activeTime.match(/\d+/)[0], 10);
        return weeks * 30; // 将周转换为天
    }

    if (activeTime.includes("近半年活跃")) {
        return 170; // 半年按180天计算
    }

    if (activeTime.includes("半年前活跃")) {
        return 180; // 半年按180天计算
    }

    // 如果匹配不上，则返回默认最大值
    return 200;
}

//沟通与否排序
document.addEventListener('DOMContentLoaded', function() {
    const sortHasCommunicatedHeader = document.getElementById('sortHasCommunicated');

    sortHasCommunicatedHeader.addEventListener('click', function() {
        sortTableByHasCommunicated();
    });
});

function sortTableByHasCommunicated() {
    let table = document.getElementById("job-table");
    let tbody = table.tBodies[0]; // 获取 tbody
    let rowsArray = Array.from(tbody.rows); // 获取所有行

    // 使用一个标志来切换排序方式：升序或降序
    let sortDescending = table.dataset.sortDescendingHasCommunicated === 'true';

    // 定义映射，将文本值映射为数值
    const valueMapping = {
        '是': 1,
        '否': 2,
        '未知': 3,
        '': 4
    };

    // 排序逻辑
    rowsArray.sort(function(rowA, rowB) {
        let valueA = rowA.getElementsByTagName("TD")[10].textContent.trim(); // 第11列，索引为10
        let valueB = rowB.getElementsByTagName("TD")[10].textContent.trim();

        let mappedA = valueMapping[valueA] || 5; // 如果未找到，默认5
        let mappedB = valueMapping[valueB] || 5;

        return sortDescending ? mappedB - mappedA : mappedA - mappedB;
    });

    // 清空 tbody 并重新插入排序后的行
    tbody.innerHTML = '';
    rowsArray.forEach(row => tbody.appendChild(row));

    // 切换排序方式
    sortDescending = !sortDescending;
    table.dataset.sortDescendingHasCommunicated = sortDescending;

    // 更新排序指示器
    updateSortIndicators('sortHasCommunicated', sortDescending);
}



// 显示职位详情
function showJobDetails(event) {
    const index = event.target.getAttribute('data-index');
    chrome.storage.local.get('jobData', function(data) {
        if (data.jobData && data.jobData[index]) {
            const job = data.jobData[index];
            showPopup();
            updatePopupContent(job);
        }
    });
}

// 更新弹出层内容
function updatePopupContent(job) {
    // 更新匹配得分
    const score = job.AI评分结果 || 0;
    const progressBar = document.querySelector('.progress');
    const scoreText = document.getElementById('scoreText');
    progressBar.style.width = `${score}%`;
    scoreText.textContent = `${score}/100`;

    // 创建一个Showdown转换器
    var converter = new showdown.Converter(),
        aiAnalysisMarkdown = job.AI分析 || 'N/A';

    // 将Markdown转换为HTML
    var aiAnalysisHtml = converter.makeHtml(aiAnalysisMarkdown);

    // 更新AI分析部分的HTML
    document.getElementById('aiAnalysis').innerHTML = aiAnalysisHtml;

    // 更新职位详情
    document.getElementById('jobTitle').textContent = job.职位名称 || 'N/A';
    document.getElementById('companyName').textContent = job.公司名称 || 'N/A';
    document.getElementById('salary').textContent = job.薪资 || 'N/A';
    document.getElementById('benefits').textContent = job.职位福利 || 'N/A';
    document.getElementById('jobDescription').textContent = job.jobDescription || 'N/A';

    // 更新前往投递按钮链接
    const applyButton = document.querySelector('.apply-button');
    applyButton.href = job.详情链接 || '#'; // 若没有提供有效链接则默认不跳转
    // 更新简历摘要
    // 从存储中获取简历数据
    chrome.storage.local.get('resume', function(data) {
        document.getElementById('resumeSummary').value = data.resume || '';
    });


}

// 显示弹出层
function showPopup() {
    document.getElementById('overlay').style.display = 'block';
}

// 隐藏弹出层
function hidePopup() {
    document.getElementById('overlay').style.display = 'none';
}

// 设置AI评分按钮
function setupProcessDataButton() {
    const processDataButton = document.getElementById('processDataButton');
    const processResultDiv = document.getElementById('processResult');
    const resume = document.getElementById('resume');

    processResultDiv.style.backgroundColor = '#ffe6e6';
    processResultDiv.style.color = '#ff0000';
    processResultDiv.style.fontWeight = 'bold';
    processResultDiv.style.fontSize = '1.5em';

    processDataButton.addEventListener('click', async function() {
        const resumeContent = resume.value;

        if (!resumeContent.trim()) {
            processResultDiv.textContent = '错误: 请输入简历内容';
            return;
        }

        processResultDiv.textContent = '正在评价...';
        processDataButton.disabled = true;

        try {
            await processJobData(resumeContent);
            processResultDiv.textContent = '处理完成';
            loadJobTable(); // 重新加载表格
        } catch (error) {
            processResultDiv.textContent = `错误: ${error.message}`;
        } finally {
            processDataButton.disabled = false;
        }
    });
}

// 处理职位数据，调用AI进行评分
async function processJobData(resumeContent) {
    const result = await chrome.storage.local.get('jobData');
    const jobDataArray = result.jobData;

    if (!jobDataArray || !Array.isArray(jobDataArray)) {
        throw new Error('无效的jobData');
    }

    const selectedIndexes = Array.from(document.querySelectorAll('.row-checkbox:checked'))
        .map(checkbox => parseInt(checkbox.getAttribute('data-index')));

    if (selectedIndexes.length === 0) {
        throw new Error('请至少选择一个职位');
    }

    let processedJobs = 0;
    let totalJobs = selectedIndexes.length;

    const updatedJobData = await Promise.all(jobDataArray.map(async (job, index) => {
        if (selectedIndexes.includes(index) && job['jobDescription']) {
            try {
                const jobTitle = job['职位名称'];
                const jobDescription = job['jobDescription'];
                const aiAnalysis = await requestAIScore(jobTitle, jobDescription, resumeContent);

                job['AI分析'] = aiAnalysis;
                job['AI评分结果'] = getScoreFromAI(aiAnalysis);
                processedJobs++;
                updateProgress(processedJobs, totalJobs, "评分");
            } catch (error) {
                console.error(`处理职位 ${job['职位名称']} 时出错:`, error);
            }
        }
        return job;
    }));

    await chrome.storage.local.set({ jobData: updatedJobData });
    console.log('已更新jobData');
    loadJobTable(); // 全部评分完成后再更新表格
    return updatedJobData;
}

// 从AI响应中提取评分
function getScoreFromAI(text) {
    const regex = /(\d+)\/100(?!\d)/g;
    let lastValidScore = null;
    let match;

    while ((match = regex.exec(text)) !== null) {
        const score = parseInt(match[1], 10);

        if (score <= 100) {
            lastValidScore = score; // 更新最后一个不大于100的分数
        }
    }

    if (lastValidScore !== null) {
        console.log(`提取的最后一个不大于100的分数是: ${lastValidScore}`);
        return lastValidScore;
    } else {
        console.log("未找到评分");
        return 0;
    }
}


// 请求AI评分
function requestAIScore(jobTitle, jobDescription, resumeContent) {
    return new Promise((resolve, reject) => {
        chrome.storage.local.get(['runMode', 'apiKey', 'model'], function(data) {
            const isOnline = data.runMode;
            const apiKey = data.apiKey;
            const modelname = data.model || 'glm-4-flash';

            const prompt = `
# 角色
你是一位具有人才招聘经验的HR专家，擅长将岗位需求与求职者简历进行对比并评分。

## 技能
1. 擅长分析用人单位给出的JD内容。
2. 擅长用户的简历，对简历与JD的匹配程度进行评分。

## 工作流
1. 先提取岗位要求，并列出具体的硬性指标。
2. 按顺序分析用户简历，判断是否满足、超出、不满足或未提及该要求。
3. 根据分析结果进行评分：完全符合得满分，部分符合扣分，不满足或未提及不得分。

## 要求
1. 若简历未满足关键硬性指标（如最低学历或经验年限），扣很多分。
2. 满分100分，评分格式为 80/100，结果必须为整数。
3. 输出结构化，包括岗位要求、简历分析、总评分，字数不超过500字。

## 示例输出格式
- 岗位要求：
  1. 学历要求：本科及以上
  2. 工作经验：3年及以上
- 简历分析：
  1. 学历：本科，符合，不扣分
  2. 工作经验：1年，不符合，扣20分
- 总评分：80/100

## 任务
请对以下JD内容和简历内容进行匹配评分：

`;

            if (isOnline) {
                // 在线模式
                const url = 'https://resume-matching-api.aitoolhub.top';
                const requestData = {
                    jobTitle: jobTitle,
                    jobDescription: jobDescription,
                    resumeContent: resumeContent,
                    modelname: modelname
                };

                fetch(url, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(requestData)
                })
                .then(async response => {
                    const text = await response.text();
                    if (!response.ok) {
                        console.error('请求失败，状态码:', response.status);
                        console.error('错误信息:', text);
                        reject(new Error(`请求失败，状态码: ${response.status}`));
                        return;
                    }
                    try {
                        const result = JSON.parse(text);
                        if (result && result.response) {
                            resolve(result.response);
                        } else {
                            console.warn('未找到 result.response，直接返回文本内容');
                            resolve(text);
                        }
                    } catch (error) {
                        console.warn('解析 JSON 时出错，假设响应为纯文本:', error);
                        resolve(text);
                    }
                })
                .catch(error => reject(error));
            } else {
                // 本地模式
                const url = 'https://open.bigmodel.cn/api/paas/v4/chat/completions';
                const data = {
                    model: modelname,
                    messages: [
                        {
                            role: "system",
                            content: prompt
                        },
                        {
                            role: "user",
                            content: `这是JD内容--职位名称: ${jobTitle}, 岗位描述: ${jobDescription},这是个人简历内容--${resumeContent}`
                        }
                    ]
                };

                fetch(url, {
                    method: 'POST',
                    headers: {
                        'Authorization': `Bearer ${apiKey}`,
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(data)
                })
                .then(async response => {
                    const text = await response.text();
                    if (!response.ok) {
                        console.error('请求失败，状态码:', response.status);
                        console.error('错误信息:', text);
                        reject(new Error(`请求失败，状态码: ${response.status}`));
                        return;
                    }
                    try {
                        const result = JSON.parse(text);
                        if (result.choices && result.choices[0] && result.choices[0].message) {
                            resolve(result.choices[0].message.content);
                        } else {
                            console.warn('未找到 result.choices[0].message，直接返回文本内容');
                            resolve(text);
                        }
                    } catch (error) {
                        console.warn('解析 JSON 时出错，假设响应为纯文本:', error);
                        resolve(text);
                    }
                })
                .catch(error => reject(error));
            }
        });
    });
}

// 开始抓取JD详情
function startFetching() {
    chrome.storage.local.get(['jobData'], function(result) {
        console.log('加载的全部职位数据:', result.jobData);

        if (result.jobData) {
            const selectedIndexes = Array.from(document.querySelectorAll('.row-checkbox:checked'))
                .map(checkbox => parseInt(checkbox.getAttribute('data-index')));

            jobQueue = result.jobData.filter((job, index) =>
                selectedIndexes.includes(index) &&
                job.详情链接 &&
                job.详情链接 !== 'N/A'
            );

            console.log('需要抓取详情的职位数量:', jobQueue.length);

            if (jobQueue.length > 0) {
                isFetching = true;
                btn.textContent = "停止加载";
                loadingIcon.style.display = 'inline-block';
                fetchAllJobs();  // 开始批量抓取
            } else {
                alert("没有选中需要抓取的职位详情");
            }
        } else {
            console.log('没有找到已保存的职位数据');
            alert("没有找到已保存的职位数据");
        }
    });
}

// 批量抓取所有职位详情
function fetchAllJobs() {
    let totalJobs = jobQueue.length;
    let processedJobs = 0;

    jobQueue.forEach((job, index) => {
        setTimeout(() => {
            fetchJobDetails(job, () => {
                processedJobs++;
                updateProgress(processedJobs, totalJobs, "JD");

                if (processedJobs === totalJobs) {
                    stopFetching();  // 所有抓取完成后停止
                    loadJobTable();  // 一次性更新表格
                }
            });
        }, index * 1000);
    });
}

// 抓取职位详情
function fetchJobDetails(job, callback) {
    if (job.详情链接) {
        chrome.runtime.sendMessage({ action: "fetchJobDetails", url: job.详情链接 }, function(response) {
            console.log('抓取职位详情响应:', response);
            callback(); // 回调表示处理完成
        });
    } else {
        callback(); // 没有有效链接时直接调用回调
    }
}

// 更新抓取和评分进度
function updateProgress(processed, total, type) {
    const task = type === "JD" ? "抓取JD" : "评分";
    processResultDiv.textContent = `已处理 ${processed} / ${total} 个${task}项`;
}

// 停止抓取JD详情
function stopFetching() {
    isFetching = false;
    btn.textContent = "获取JD";
    loadingIcon.style.display = 'none';
    console.log('停止抓取');
}

// 监听从后台发送的消息，处理JD抓取结果
chrome.runtime.onMessage.addListener((message, sender, sendResponse) => {
    if (message.action === "jobDetailsFetched") {
        if (message.success) {
            console.log('JD获取成功:', message.data);
            // 更新 jobData
            chrome.storage.local.get(['jobData'], function(result) {
                if (chrome.runtime.lastError) {
                    console.error('获取 jobData 时发生错误:', chrome.runtime.lastError);
                    return;
                }

                let updatedJobData = result.jobData.map(j => {
                    if (j.详情链接 === message.url) {
                        return { ...j, ...message.data }; // 更新职位信息
                    }
                    return j;
                });

                // 保存更新后的 jobData
                chrome.storage.local.set({ jobData: updatedJobData }, function() {
                    if (chrome.runtime.lastError) {
                        console.error('保存 jobData 时发生错误:', chrome.runtime.lastError);
                    } else {
                        console.log('职位详情已更新并保存');
                    }
                });
            });
        } else {
            console.error('JD获取失败:', message.error);
        }
    }
});

// 选中行的处理，添加或移除选中状态的样式
document.addEventListener('change', function(e) {
    if (e.target && e.target.classList.contains('row-checkbox')) {
        const row = e.target.closest('tr');
        if (e.target.checked) {
            row.classList.add('state-selected');
        } else {
            row.classList.remove('state-selected');
        }
    }
});


//导出岗位数据
document.getElementById('exportJobData').addEventListener('click', function() {
    // 获取chrome.storage.local中的岗位数据
    chrome.storage.local.get('jobData', function(result) {
        const jobData = result.jobData || [];
        
        if (jobData.length === 0) {
            alert('没有岗位数据可以导出');
            return;
        }
        
        // 使用xlsx库创建一个工作簿
        const worksheet = XLSX.utils.json_to_sheet(jobData);
        const workbook = XLSX.utils.book_new();
        XLSX.utils.book_append_sheet(workbook, worksheet, '岗位数据');

        // 将数据导出为xlsx文件
        XLSX.writeFile(workbook, 'job_data.xlsx');
    });
});


//表格选择逻辑
document.addEventListener('DOMContentLoaded', function () {
    const jobTable = document.getElementById('job-table');
    const selectAllCheckbox = document.getElementById('select-all');
    let lastSelectedIndex = null;

    // 单击选择行
    jobTable.addEventListener('click', function (event) {
        const targetRow = event.target.closest('tr');
        
        // 如果点击的是复选框，则不执行行的点击事件
        if (event.target.type === 'checkbox') {
            // 复选框点击时，手动处理选中状态的样式
            const checkbox = event.target;
            if (checkbox.checked) {
                targetRow.classList.add('selected'); // 添加选中样式
            } else {
                targetRow.classList.remove('selected'); // 移除选中样式
            }
            return;
        }

        if (targetRow && targetRow.rowIndex > 0) { // 确保点击的是数据行而不是标题行
            const checkbox = targetRow.querySelector('input[type="checkbox"]');
            if (event.shiftKey && lastSelectedIndex !== null) {
                // Shift 多选逻辑
                const currentIndex = targetRow.rowIndex;
                const start = Math.min(lastSelectedIndex, currentIndex);
                const end = Math.max(lastSelectedIndex, currentIndex);

                for (let i = start; i <= end; i++) {
                    const row = jobTable.rows[i];
                    const rowCheckbox = row.querySelector('input[type="checkbox"]');
                    rowCheckbox.checked = true;
                    row.classList.add('selected'); // 添加选中样式
                }
            } else {
                // 单击选中当前行
                checkbox.checked = !checkbox.checked;
                if (checkbox.checked) {
                    targetRow.classList.add('selected'); // 添加选中样式
                } else {
                    targetRow.classList.remove('selected'); // 移除选中样式
                }
                lastSelectedIndex = targetRow.rowIndex;
            }
        }
    });

    // 选中所有行
    selectAllCheckbox.addEventListener('change', function () {
        const allCheckboxes = jobTable.querySelectorAll('tbody input[type="checkbox"]');
        allCheckboxes.forEach(checkbox => {
            checkbox.checked = selectAllCheckbox.checked;
            const row = checkbox.closest('tr');
            if (selectAllCheckbox.checked) {
                row.classList.add('selected'); // 添加选中样式
            } else {
                row.classList.remove('selected'); // 移除选中样式
            }
        });
    });
});

//隐藏岗位
document.getElementById('hideSelectedResumes').addEventListener('click', function () {
    chrome.storage.local.get('jobData', function (data) {
        const jobData = data.jobData || [];
        const checkboxes = document.querySelectorAll('.row-checkbox:checked');

        // 更新选中项的是否隐藏字段
        checkboxes.forEach(cb => {
            const index = parseInt(cb.getAttribute('data-index'));
            jobData[index].是否隐藏 = '是'; // 标记为已隐藏
        });

        // 保存更新后的 jobData
        chrome.storage.local.set({ jobData: jobData }, function () {
            // alert('选中的简历已隐藏');
            loadJobTable(); // 重新加载简历分析页面表格
        });
    });
});

function loadHiddenJobTable() {
    chrome.storage.local.get('jobData', function (data) {
        const jobData = data.jobData || [];
        const tbody = document.querySelector('#hidden-job-table tbody');
        tbody.innerHTML = '';

        // 只显示标记为"是否隐藏: 是"的岗位
        jobData.forEach((job, index) => {
            if (job.是否隐藏 === '是') {
                const row = tbody.insertRow();
                row.innerHTML = `
                    <td><input type="checkbox" class="row-checkbox-hidden" data-index="${index}"></td>
                    <td>${job.职位名称 || 'N/A'}</td>
                    <td>${job.工作地点 || 'N/A'}</td>
                    <td>${job.薪资 || 'N/A'}</td>
                    <td>${job.公司名称 || 'N/A'}</td>
                    <td>${job.工作经验 || 'N/A'}</td>
                    <td>${job.学历要求 || 'N/A'}</td>
                    <td class="job-benefits-column" title="${job.职位福利 || 'N/A'}">${job.职位福利 || 'N/A'}</td>
                    <td>${job.activeTime || 'N/A'}</td>
                    <td>${job.抓取时间 || 'N/A'}</td>
                    <td>${job.hasCommunicated || 'N/A'}</td>
                    <td>${job.AI评分结果 !== undefined ? job.AI评分结果 : 'N/A'}</td>
                    <td><button class="details-btn" data-index="${index}">详情</button></td>
                `;
            }
        });

        // 为所有详情按钮添加点击事件监听器
        const detailButtons = document.querySelectorAll('.details-btn');
        detailButtons.forEach(button => {
            button.addEventListener('click', showJobDetails);
        });
    });
}


document.getElementById('restoreSelectedJobs').addEventListener('click', function () {
    chrome.storage.local.get('jobData', function (data) {
        const jobData = data.jobData || [];
        const checkboxes = document.querySelectorAll('.row-checkbox-hidden:checked');

        // 更新选中项的是否隐藏字段为"否"
        checkboxes.forEach(cb => {
            const index = parseInt(cb.getAttribute('data-index'));
            jobData[index].是否隐藏 = '否'; // 恢复显示
        });

        // 保存更新后的 jobData
        chrome.storage.local.set({ jobData: jobData }, function () {
            // alert('选中的简历已恢复');
            loadHiddenJobTable(); // 重新加载隐藏岗位页面表格
            loadJobTable(); // 重新加载简历分析页面表格
        });
    });
});



document.getElementById('hideSelectedResumes').addEventListener('click', function () {
    chrome.storage.local.get('jobData', function (data) {
        const jobData = data.jobData || [];
        const checkboxes = document.querySelectorAll('.row-checkbox:checked');

        // 更新选中项的是否隐藏字段
        checkboxes.forEach(cb => {
            const index = parseInt(cb.getAttribute('data-index'));
            jobData[index].是否隐藏 = '是'; // 标记为已隐藏
        });

        // 保存更新后的 jobData
        chrome.storage.local.set({ jobData: jobData }, function () {
            alert('选中的简历已隐藏');
            loadJobTable(); // 重新加载简历分析页面表格
        });
    });
});

// 批量打招呼功能
// 获取 processResultDiv 元素
const processResultDiv = document.getElementById('processResult');

// 批量打招呼功能
document.addEventListener('DOMContentLoaded', function() {
    const greetButton = document.getElementById('greetSelectedJobs');

    // 绑定批量打招呼功能
    greetButton.addEventListener('click', function() {
        console.log("批量打招呼按钮被点击，开始处理选中的岗位...");
        const selectedJobs = getSelectedJobs();
        console.log(`已选择的岗位数量: ${selectedJobs.length}`);

        // 初始化进度显示
        processResultDiv.textContent = `开始处理 ${selectedJobs.length} 个岗位...`;

        batchGreetJobs(selectedJobs);
    });
});

function getSelectedJobs() {
    const selectedJobs = [];
    const checkboxes = document.querySelectorAll('.row-checkbox:checked'); 
    console.log(`发现 ${checkboxes.length} 个选中的复选框`);

    checkboxes.forEach(checkbox => {
        const jobRow = checkbox.closest('tr');
        const jobLink = jobRow.dataset.jobLink || '#';
        console.log(`岗位详情链接: ${jobLink}`);
        selectedJobs.push({ link: jobLink });
    });
    return selectedJobs;
}



function batchGreetJobs(jobs) {
    let totalJobs = jobs.length;
    let processedJobs = 0;

    if (totalJobs === 0) {
        processResultDiv.textContent = '未选择任何岗位';
        return;
    }

    jobs.forEach((job, index) => {
        console.log(`开始处理第 ${index + 1} 个岗位，链接: ${job.link}`);

        setTimeout(() => {
            openJobAndGreet(job, () => {
                processedJobs++;
                updateProgress(processedJobs, totalJobs);

                // 如果所有岗位都已处理完成
                if (processedJobs === totalJobs) {
                    processResultDiv.textContent = `所有 ${totalJobs} 个岗位已处理完成`;
                }
            });
        }, index * 5000); // 每隔5秒处理一个岗位
    });
}

function openJobAndGreet(job, callback) {
    if (job.link !== '#') {
        chrome.tabs.create({ url: job.link, active: false }, function(tab) {
            chrome.tabs.onUpdated.addListener(function listener(tabId, changeInfo, updatedTab) {
                if (tabId === tab.id && changeInfo.status === 'complete') {
                    chrome.tabs.onUpdated.removeListener(listener);

                    chrome.scripting.executeScript({
                        target: { tabId: tab.id },
                        files: ['contentScript.js']
                    }, function() {
                        console.log(`已在标签页 ${tab.id} 中执行内容脚本`);

                        // 调用回调函数，表示处理完成
                        if (typeof callback === 'function') {
                            callback();
                        }
                    });
                }
            });
        });
    } else {
        console.log(`无有效链接，跳过该岗位`);

        // 调用回调函数，表示处理完成
        if (typeof callback === 'function') {
            callback();
        }
    }
}

function updateProgress(processed, total) {
    processResultDiv.textContent = `已处理 ${processed} / ${total} 个岗位`;
}

// 更新表格行的函数
function updateTableRowHasCommunicated(updatedUrl) {
    const rows = document.querySelectorAll('#job-table tbody tr');
    let targetRow = null;

    rows.forEach(row => {
        if (row.dataset.jobLink === updatedUrl) {
            targetRow = row;
        }
    });

    if (targetRow) {
        // 假设 hasCommunicated 是表格的第 11 列（索引为 10）
        const hasCommunicatedCell = targetRow.cells[10];
        hasCommunicatedCell.textContent = '是';

        // 添加高亮效果
        targetRow.classList.add('updated-row');
        setTimeout(() => {
            targetRow.classList.remove('updated-row');
        }, 2000); // 2秒后移除高亮效果

        console.log(`已更新表格中对应行的 hasCommunicated 状态`);
    } else {
        console.log(`未找到匹配的表格行，无法更新`);
    }
}
