function updateTotalPagesDisplay() {
    chrome.storage.local.get(['pagesToScrape'], function(data) {
        const totalPages = data.pagesToScrape || 5;
        document.getElementById('totalPagesInput').value = totalPages;
    });
}

document.getElementById('totalPagesInput').addEventListener('input', function() {
    const newTotalPages = parseInt(this.value) || 5;
    chrome.storage.local.set({pagesToScrape: newTotalPages}, function() {
        console.log(`总页数已更新为: ${newTotalPages}`);
    });
});


// 当弹窗加载时，更新 totalPages 显示
document.addEventListener('DOMContentLoaded', function() {
    updateTotalPagesDisplay();
});

// 当弹窗获得焦点时，更新 totalPages 显示
window.addEventListener('focus', function() {
    updateTotalPagesDisplay();
});

document.getElementById('scrapeData').addEventListener('click', function() {
    // 从存储中获取要抓取的总页数
    chrome.storage.local.get(['pagesToScrape'], function(data) {
        const totalPages = data.pagesToScrape || 5; // 默认抓取5页
        // 开始抓取，从第1页开始
        startScraping(1, totalPages, []);
    });
});


function startScraping(currentPage, totalPages, allJobData) {

    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
        const tabId = tabs[0].id;
        const tabUrl = tabs[0].url;

        // 更新标签页到目标页码的URL
        const nextPageUrl = updatePageUrl(tabUrl, currentPage);
        chrome.tabs.update(tabId, {url: nextPageUrl}, function() {
            // 等待标签页加载完成
            chrome.tabs.onUpdated.addListener(function listener(tabIdUpdated, changeInfo, tab) {
                if (tabIdUpdated === tabId && changeInfo.status === 'complete') {
                    chrome.tabs.onUpdated.removeListener(listener);

                    // 在新页面上注入抓取脚本
                    chrome.scripting.executeScript({
                        target: {tabId: tabId},
                        func: scrapeCurrentPageData,
                        args: [currentPage],
                    }, function(results) {
                        if (chrome.runtime.lastError) {
                            console.error(chrome.runtime.lastError);
                            alert('数据抓取失败，请查看控制台获取详细信息');
                        } else {
                            const jobData = results[0].result;
                            allJobData.push(...jobData);
                            console.log(`成功抓取第 ${currentPage} 页数据:`, jobData);

                            if (currentPage < totalPages) {
                                // 继续抓取下一页
                                startScraping(currentPage + 1, totalPages, allJobData);
                            } else {
                                // 完成所有抓取
                                finishScraping(allJobData);
                            }
                        }
                    });
                }
            });
        });
    });
}

function updatePageUrl(currentUrl, pageNumber) {
    let url = new URL(currentUrl);
    url.searchParams.set('page', pageNumber);
    return url.toString();
}

function finishScraping(allJobData) {
    console.log('所有页面的工作数据收集完成:', allJobData);
    // 发送数据到后台脚本进行存储
    chrome.runtime.sendMessage({type: 'SAVE_JOB_DATA', data: allJobData});
    // 打开设置页面
    chrome.runtime.openOptionsPage();
}

function scrapeCurrentPageData(currentPage) {
    return new Promise(async (resolve, reject) => {
        function delay(ms) {
            return new Promise(resolve => setTimeout(resolve, ms));
        }

        async function waitForPageLoad() {
            let retries = 0;
            const maxRetries = 10;
            while (retries < maxRetries) {
                const jobs = document.querySelectorAll('.job-card-wrapper');
                if (jobs.length > 0) {
                    console.log(`页面加载完成，找到 ${jobs.length} 个工作卡片`);
                    return;
                }
                console.log(`等待页面加载，尝试次数: ${retries + 1}`);
                await delay(1000); // 等待1秒
                retries++;
            }
            console.error('页面加载超时');
            reject('页面加载超时');
        }

        try {
            await waitForPageLoad();

            const jobData = [];
            const jobs = document.querySelectorAll('.job-card-wrapper');
            jobs.forEach(job => {
                const jobLinkElement = job.querySelector('a[ka*="search_list_jname"]');
                let jobInfo = {
                    职位名称: jobLinkElement ? jobLinkElement.querySelector('span.job-name') ? jobLinkElement.querySelector('span.job-name').innerText.trim() : 'N/A' : 'N/A',
                    工作地点: job.querySelector('span.job-area') ? job.querySelector('span.job-area').innerText.trim() : 'N/A',
                    薪资: job.querySelector('span.salary') ? job.querySelector('span.salary').innerText.trim() : 'N/A',
                    公司名称: job.querySelector('h3.company-name a') ? job.querySelector('h3.company-name a').innerText.trim() : 'N/A',
                    职位福利: job.querySelector('div.info-desc') ? job.querySelector('div.info-desc').innerText.trim() : 'N/A',
                    工作经验: job.querySelectorAll('ul.tag-list li')[0] ? job.querySelectorAll('ul.tag-list li')[0].innerText.trim() : 'N/A',
                    学历要求: job.querySelectorAll('ul.tag-list li')[1] ? job.querySelectorAll('ul.tag-list li')[1].innerText.trim() : 'N/A',
                    详情链接: jobLinkElement ? jobLinkElement.href.split('.html')[0] + '.html' : 'N/A', // 只保留.html之前的部分
                    抓取时间: new Date().toLocaleString(),
                    页码: currentPage
                };

                jobData.push(jobInfo);
            });

            resolve(jobData);
        } catch (error) {
            reject(error);
        }
    });
}

document.getElementById('settings').addEventListener('click', () => {

        window.open(chrome.runtime.getURL('options.html'));

});

chrome.runtime.onMessage.addListener(function(message, sender, sendResponse) {
    if (message.action === 'dataFetched') {
        console.log('数据抓取成功:', message.data);
        alert(`爬取完成，新增 ${message.addedCount} 条数据，总共 ${message.data.length} 条数据`);
        window.open(chrome.runtime.getURL('options.html'));
    } else if (message.action === 'dataFetchFailed') {
        console.error('数据抓取失败:', message.error);
        alert('数据抓取失败，请查看控制台获取详细信息');
    }
});



// 添加打招呼语的事件监听器
document.getElementById('generateGreeting').addEventListener('click', function() {
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
        const currentUrl = tabs[0].url;

        // 检查URL格式
        if (!currentUrl.includes('zhipin.com/job_detail')) {
            alert('错误: 不在岗位详情页面');
            return;
        }

        // 在当前标签页执行脚本以获取职位描述
        chrome.scripting.executeScript({
            target: {tabId: tabs[0].id},
            function: getJobDescription
        }, function(results) {
            if (chrome.runtime.lastError) {
                console.error(chrome.runtime.lastError);
                alert('获取职位描述失败');
                return;
            }
        
            if (!results || results.length === 0) {
                alert('错误: 未能获取职位信息');
                return;
            }
        
            const { jobDescription, jobTitle } = results[0].result;
            if (jobDescription === '未找到职位描述') {
                alert('错误: 未找到职位描述');
                return;
            }

            // 获取简历内容
            chrome.storage.local.get(['resume'], function(data) {
                const resume = data.resume || '';
                if (!resume) {
                    alert('错误: 请输入简历内容');
                    return;
                }

                // 调用生成打招呼语的函数（这里只是一个占位函数）
                generateGreetingMessage(jobDescription,jobTitle, resume);
            });
        });
    });
});

// 获取职位描述的函数
function getJobDescription() {
    const jobDescription = document.querySelector('.job-sec-text')?.textContent.trim() || '未找到职位描述';
    const jobTitle = document.querySelector('.name h1')?.textContent.trim() || '未找到职位名称';
    
    return { jobDescription, jobTitle };
}

// 生成打招呼语的函数（占位函数，需要后续实现）
function generateGreetingMessage(jobDescription,jobTitle, resume) {
    // 这里是生成打招呼语的逻辑
    console.log('职位描述:', jobDescription);
    console.log('简历内容:', resume);
    chrome.tabs.query({active: true, currentWindow: true}, function(tabs) {
        const currentUrl = tabs[0].url;
        
        // 显示加载提示
        document.getElementById('greetingResult').textContent = '正在生成打招呼语，请稍候...';

        requestAIGreetingMessage(jobTitle, jobDescription, resume)
            .then(greeting => {
                // 显示生成的打招呼语
                document.getElementById('greetingResult').textContent = greeting;
                
                // 复制到剪贴板
                navigator.clipboard.writeText(greeting).then(() => {
                    console.log('打招呼语已复制到剪贴板');
                }).catch(err => {
                    console.error('复制到剪贴板失败:', err);
                });
            })
            .catch(error => {
                console.error('生成打招呼语失败:', error);
                document.getElementById('greetingResult').textContent = '生成打招呼语失败，请重试';
            });
    });
}


// 请求AI评分
function requestAIGreetingMessage(jobTitle, jobDescription, resumeContent) {
    return new Promise((resolve, reject) => {
        chrome.storage.local.get(['runMode', 'apiKey', 'model'], function(data) {
            const isOnline = data.runMode;
            const apiKey = data.apiKey;
            const modelname = data.model || 'glm-4-flash';

            const GreetingMessageprompt = `
# 角色
# Role: 招聘助手

## Profile

- Language: 中文
- Description: 招聘助手是一个专门设计用于帮助求职者根据特定岗位描述和个人简历，生成吸引招聘方的打招呼语的角色。

## Knowledges

- 招聘流程和求职技巧
- 常见岗位描述的理解
- 个人简历的亮点分析

## Skills

- 文本生成能力
- 对岗位描述和个人简历的分析能力
- 创造吸引人的打招呼语的能力

## Rules

- 必须基于提供的岗位描述和个人简历信息生成文本
- 文本需要符合正式且礼貌的商务沟通风格
- 文本应突出求职者的个人优势与岗位匹配度
- 描述最符合岗位需求的3个点
- 口语化

## Constraints

- 生成的文本长度精炼而突出重点
- 文本内容需积极正面，体现求职者的热情和诚意
- 格式类似—您好，注意到贵公司正在招聘{岗位名称}，我对这个职位非常感兴趣，我{个人优势，只有三句话}，如果觉得合适，我们可以进一步沟通，其期待您的回复!

## Workflow

1. 用户提供岗位描述和个人简历信息
2. AI分析岗位描述，提取关键要求
3. AI分析个人简历，找出与岗位匹配的优势
4. AI根据以上信息生成打招呼语
5. 输出最终文本

## Initialization

作为招聘助手，我的任务是帮助求职者制作专业的自我介绍。请提供您想要申请的岗位描述和个人简历，我将为您生成一句吸引人的打招呼语。

`;

            if (isOnline) {
                // 在线模式
                const url = 'https://resume-matching-api.aitoolhub.top/greeting';
                const requestData = {
                    jobTitle: jobTitle,
                    jobDescription: jobDescription,
                    resumeContent: resumeContent,
                    modelname: modelname
                };

                fetch(url, {
                    method: 'POST',
                    headers: {
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(requestData)
                })
                .then(async response => {
                    const text = await response.text();
                    if (!response.ok) {
                        console.error('请求失败，状态码:', response.status);
                        console.error('错误信息:', text);
                        reject(new Error(`请求失败，状态码: ${response.status}`));
                        return;
                    }
                    try {
                        const result = JSON.parse(text);
                        if (result && result.response) {
                            resolve(result.response);
                        } else {
                            console.warn('未找到 result.response，直接返回文本内容');
                            resolve(text);
                        }
                    } catch (error) {
                        console.warn('解析 JSON 时出错，假设响应为纯文本:', error);
                        resolve(text);
                    }
                })
                .catch(error => reject(error));
            } else {
                // 本地模式
                const url = 'https://open.bigmodel.cn/api/paas/v4/chat/completions';
                const data = {
                    model: modelname,
                    messages: [
                        {
                            role: "system",
                            content: GreetingMessageprompt
                        },
                        {
                            role: "user",
                            content: `这是JD内容--职位名称: ${jobTitle}, 岗位描述: ${jobDescription},这是个人简历内容--${resumeContent}`
                        }
                    ]
                };

                fetch(url, {
                    method: 'POST',
                    headers: {
                        'Authorization': `Bearer ${apiKey}`,
                        'Content-Type': 'application/json'
                    },
                    body: JSON.stringify(data)
                })
                .then(async response => {
                    const text = await response.text();
                    if (!response.ok) {
                        console.error('请求失败，状态码:', response.status);
                        console.error('错误信息:', text);
                        reject(new Error(`请求失败，状态码: ${response.status}`));
                        return;
                    }
                    try {
                        const result = JSON.parse(text);
                        if (result.choices && result.choices[0] && result.choices[0].message) {
                            resolve(result.choices[0].message.content);
                        } else {
                            console.warn('未找到 result.choices[0].message，直接返回文本内容');
                            resolve(text);
                        }
                    } catch (error) {
                        console.warn('解析 JSON 时出错，假设响应为纯文本:', error);
                        resolve(text);
                    }
                })
                .catch(error => reject(error));
            }
        });
    });
}

document.getElementById('copyGreeting').addEventListener('click', function() {
    const greetingText = document.getElementById('greetingResult').textContent;
    navigator.clipboard.writeText(greetingText).then(() => {
        alert('打招呼语已复制到剪贴板');
    }).catch(err => {
        console.error('复制到剪贴板失败:', err);
        alert('复制失败，请手动复制');
    });
});